@@ -106,6 +106,7 @@ void InstWizard::internalWizard()
 		<< " <a href=\"http://www.xinehq.de\">http://www.xinehq.de</a>.</font>";
 	*/
 	//WIN32-CODECS
+	/*
 	info << "<hr><b>" << i18n("WIN32 Codecs") << "...</b><br>";
 	TQDir d("/usr/lib/win32");
 	TQStringList entries = d.entryList("wmv*");
@@ -114,12 +115,12 @@ void InstWizard::internalWizard()
 	else
 		info << "<font color=\"DarkRed\">" << i18n("No WIN32 codecs found in /usr/lib/win32. You're not able to play Windows Media 9 files, newer Real Media files and some less common formats. Download the codecs here:")
 		<< " <a href=\"http://www1.mplayerhq.hu/design7/dload.html#binary_codecs\">http://www1.mplayerhq.hu/design7/dload.html#binary_codecs</a>.</font>";
-
+	*/
 	//LIBDVDCSS
 	info << "<br><hr><b>" << "libdvdcss" << "...</b><br>";
 	bool dvdcss = false;
-	d = TQDir("/usr/lib");
-	entries = d.entryList("libdvdcss.so*");
+	TQDir d("/usr/lib");
+	TQStringList entries = d.entryList("libdvdcss.so*");
 	if (entries.count())
 		dvdcss = true;
 	else
