@@ -23,7 +23,7 @@
 #include <tqxml.h>
 
 #include <kdebug.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 
 #include "playlistimport.h"
 
@@ -449,12 +449,12 @@ bool PlaylistImport::ram(const MRL& playlist, TQValueList<MRL>& mrls, TQWidget*
 	kdDebug() << "PlaylistImport: Seems to be a ram playlist!" << endl;
 
 	TQString localFile, url;
-	if (KIO::NetAccess::mimetype(playlist.kurl(), parent) == "application/vnd.rn-realmedia") {
+	if (TDEIO::NetAccess::mimetype(playlist.kurl(), parent) == "application/vnd.rn-realmedia") {
 		kdDebug() << "PlaylistImport: Seems to be a real media file" << endl;
 		return false;
 	}
 
-	if (KIO::NetAccess::download(playlist.kurl(), localFile, parent))
+	if (TDEIO::NetAccess::download(playlist.kurl(), localFile, parent))
 	{
 		TQFile plFile(localFile);
 		if (!plFile.open(IO_ReadOnly)) return false;
@@ -475,7 +475,7 @@ bool PlaylistImport::ram(const MRL& playlist, TQValueList<MRL>& mrls, TQWidget*
 		}
 	}
 	else {
-		kdError() << "PlaylistImport: " << KIO::NetAccess::lastErrorString() << endl;
+		kdError() << "PlaylistImport: " << TDEIO::NetAccess::lastErrorString() << endl;
                 return false;
         }
 
